/*
cdcd - Command Driven CD player
Copyright (C) 1998-99 Tony Arcieri
Copyright (C) 2001, 2002, 2003 Fabrice Bauzac

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef INTERFACE_H
#define INTERFACE_H

#include "cdaudio.h"

int cddb_get_siteslist (struct cddb_serverlist *list, struct cddb_host host);
int cdcd_cd_stat (int cd_desc, struct disc_info *disc);
void cddb_lookup (int cd_desc, struct disc_data *data);
void cddb_submit (int cd_desc, char *email_address);
void lookup_now (int cd_desc, struct disc_data *data);

#endif /* INTERFACE_H */
